@@ -10,32 +10,32 @@ import numpy as np
 
 
 class Quantity:
-    """Object containing information about a quantity with the corresponding label and unit.
+    """Object containing information about a quantity with the corresponding short_name and unit.
 
-    :ivar label: The short label representing the quantity.
+    :ivar short_name: The short short_name representing the quantity.
     :ivar quantity: The name of the quantity.
     :ivar unit: The corresponding unit of the quantity.
     """
-    def __init__(self, quantity: str, label: str, unit: str):
-        self.label = label
+    def __init__(self, quantity: str, short_name: str, unit: str):
+        self.short_name = short_name
         self.unit = unit
         self.name = quantity
 
     def __eq__(self, other):
-        return self.name == other.name and self.label == other.label and self.unit == other.unit
+        return self.name == other.name and self.short_name == other.short_name and self.unit == other.unit
 
     def __hash__(self):
-        return hash(self.label)
+        return hash(self.short_name)
 
     def __repr__(self):
-        return f"Quantity('{self.label}')"
+        return f"Quantity('{self.short_name}')"
 
 
 class Device:
     """Represents a single Device.
 
     :ivar id: The id the device was given.
-    :ivar quantity: The quantity the device measured.
+    :ivar quantity: The :class:`Quantity` the device measured.
     :ivar position: Position of the device in the simulation space.
     :ivar orientation: The direction the device was facing.
     :ivar data: All data the device measured.
@@ -73,6 +73,23 @@ class Device:
         return f"Device(id='{self.id}', xyz={self.position}, quantity={self.quantity})"
 
 
+class Profile:
+    """Class containing profile data.
+    """
+    def __init__(self, profile_id: str, times: np.ndarray, npoints: np.ndarray, depths: np.ndarray, values: np.ndarray):
+        self.id = profile_id
+        self.times = times
+        self.npoints = npoints
+        self.depths = depths
+        self.values = values
+
+    def __eq__(self, other):
+        return self.id == other.id
+
+    def __repr__(self):
+        return f"Profile(id='{self.id}', times={self.times}, depths={self.depths}, values={self.values})"
+
+
 def create_hash(path: str):
     """Returns the md5 hash as string for the given file.
     """
